Inspect and query JavaFX scene graphs from Clojure.
el is a scene graph element, e.g., Node, Window, Scene, or synthetic ROOT.
Public entry points:
props for reading supported properties from an eltree for building a nested representation of an el and its childrenall and one for querying the live JavaFX graphExamples:
(props el :only [:id :text])
(tree :depth 3)
(tree el :props [:id])
(all Text)
(one "#root")
(key-press! el :alt)
(mouse-press! el :primary)
(mouse-release! el :primary)
(key-release! el :alt)
Inspect and query JavaFX scene graphs from Clojure. `el` is a scene graph element, e.g., Node, Window, Scene, or synthetic ROOT. Public entry points: - `props` for reading supported properties from an el - `tree` for building a nested representation of an el and its children - `all` and `one` for querying the live JavaFX graph Examples: ```clojure (props el :only [:id :text]) (tree :depth 3) (tree el :props [:id]) (all Text) (one "#root") (key-press! el :alt) (mouse-press! el :primary) (mouse-release! el :primary) (key-release! el :alt) ```
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |